@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 from ktplotspy.plot.plot_cpdb import plot_cpdb
+from ktplotspy.plot.plot_cpdb_chord import plot_cpdb_chord
 from ktplotspy.plot.plot_cpdb_heatmap import plot_cpdb_heatmap
 
-__all__ = ["plot_cpdb", "plot_cpdb_heatmap"]
+__all__ = ["plot_cpdb", "plot_cpdb_chord", "plot_cpdb_heatmap"]
